@@ -6,7 +6,7 @@ use warnings;
 use Moo;
 use MooX::Types::MooseLike::Base qw/ ArrayRef HashRef Int Str /;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use Data::Dump 'dump';
 use DateTime;
@@ -233,7 +233,7 @@ sub capture_errors {
 
     my ($stacktrace, @retval);
     eval {
-        local $SIG{__DIE__} = sub { $stacktrace = Devel::StackTrace->new() };
+        local $SIG{__DIE__} = sub { $stacktrace = Devel::StackTrace->new(skip_frames => 1) };
 
         if ($wantarray) {
             @retval = $subref->();
@@ -250,10 +250,7 @@ sub capture_errors {
 
         my %stacktrace_context = $stacktrace
             ? $self->stacktrace_context(
-                $self->_get_frames_from_devel_stacktrace(
-                    $stacktrace,
-                    2, # ignore 2 frames: Devel::StackTrace->new, $SIG{__DIE__}->()
-                ),
+                $self->_get_frames_from_devel_stacktrace($stacktrace),
             )
             : ();
 
@@ -275,9 +272,7 @@ sub capture_errors {
 };
 
 sub _get_frames_from_devel_stacktrace {
-    my ($self, $stacktrace, $ignore_num_frames) = @_;
-
-    $ignore_num_frames ||= 0;
+    my ($self, $stacktrace) = @_;
 
     my @frames = map {
         my $frame = $_;
@@ -295,7 +290,13 @@ sub _get_frames_from_devel_stacktrace {
         }
     } $stacktrace->frames();
 
-    shift(@frames) while ($ignore_num_frames--);
+    # Devel::Stacktrace::Frame's subroutine() and args() describe what's being called by the current frame,
+    # whereas Sentry expects function and vars to describe the current frame.
+    for my $i (0..$#frames) {
+        my $frame = $frames[$i];
+        my $parent = $frames[$i + 1] // {};
+        @$frame{'function', 'vars'} = @$parent{'function', 'vars'};
+    }
 
     return [ reverse(@frames) ];
 }
